import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';
import 'package:flutter_hls_audio_player_platform_interface/flutter_hls_audio_player_platform_interface.dart';

/// See [play] method as well as example app on how to use.
class Audio {
  /// Plays given [url] with native player. The [title] and [subtitle]
  /// are used for lock screen info panel on both iOS & Android. Optionally pass
  /// in current [position] to start playback from that point. The
  /// [isLiveStream] flag is only used on iOS to change the scrub-bar look
  /// on lock screen info panel. It has no affect on the actual functionality
  /// of the plugin. Defaults to false.
  Future<void> play(String url,
      {String title = "",
      String subtitle = "",
      Duration position = Duration.zero,
      bool isLiveStream = false,
      String token ="",
        String image = ""
      }) async {
    debugPrint("play called");
    await FlutterHlsAudioPlayerPlatform.instance.play(url,title: title,token: token,image: image,isLiveStream: false,position: position);
  }

  Future<void> pause() async {
    await FlutterHlsAudioPlayerPlatform.instance.pause();
  }

  Future<void> stop() async {
    await FlutterHlsAudioPlayerPlatform.instance.stop();
  }

  Future<void> seekTo(double seconds) async {
    await FlutterHlsAudioPlayerPlatform.instance.seekTo(seconds);
  }

  Future<void> dispose() async {
    await stop();
  }
}
